@@ -1,5 +1,5 @@
-#------------------------------------------------------------------------------
-# Copyright (c) 2020, 2022, Oracle and/or its affiliates.
+# -----------------------------------------------------------------------------
+# Copyright (c) 2020, 2025, Oracle and/or its affiliates.
 #
 # This software is dual-licensed to you under the Universal Permissive License
 # (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl and Apache License
@@ -20,47 +20,20 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-#------------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
 
-#------------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
 # constants.py
 #
 # Contains the constants defined by the package.
-#------------------------------------------------------------------------------
-
-# mandated DB API constants
-apilevel = "2.0"
-threadsafety = 2
-paramstyle = "named"
-
-# authentication modes
-AUTH_MODE_DEFAULT = 0
-AUTH_MODE_PRELIM = 0x00000008
-AUTH_MODE_SYSASM = 0x00008000
-AUTH_MODE_SYSBKP = 0x00020000
-AUTH_MODE_SYSDBA = 0x00000002
-AUTH_MODE_SYSDGD = 0x00040000
-AUTH_MODE_SYSKMT = 0x00080000
-AUTH_MODE_SYSOPER = 0x00000004
-AUTH_MODE_SYSRAC = 0x00100000
-
-# pool "get" modes
-POOL_GETMODE_WAIT = 0
-POOL_GETMODE_NOWAIT = 1
-POOL_GETMODE_FORCEGET = 2
-POOL_GETMODE_TIMEDWAIT = 3
-
-# purity values
-PURITY_DEFAULT = 0
-PURITY_NEW = 1
-PURITY_SELF = 2
+# -----------------------------------------------------------------------------
 
 # AQ delivery modes
-MSG_BUFFERED =  2
+MSG_BUFFERED = 2
 MSG_PERSISTENT = 1
 MSG_PERSISTENT_OR_BUFFERED = 3
 
-# AQ deque modes
+# AQ dequeue modes
 DEQ_BROWSE = 1
 DEQ_LOCKED = 2
 DEQ_REMOVE = 3
@@ -77,7 +50,7 @@ DEQ_ON_COMMIT = 2
 
 # AQ dequeue wait modes
 DEQ_NO_WAIT = 0
-DEQ_WAIT_FOREVER = 2 ** 32 - 1
+DEQ_WAIT_FOREVER = 2**32 - 1
 
 # AQ enqueue visibility modes
 ENQ_IMMEDIATE = 1
@@ -145,19 +118,10 @@ OPCODE_DROP = 0x20
 OPCODE_INSERT = 0x02
 OPCODE_UPDATE = 0x04
 
-# flags for tpc_begin()
-TPC_BEGIN_JOIN = 0x00000002
-TPC_BEGIN_NEW = 0x00000001
-TPC_BEGIN_PROMOTE = 0x00000008
-TPC_BEGIN_RESUME = 0x00000004
-
 # flags for tpc_end()
 TPC_END_NORMAL = 0
 TPC_END_SUSPEND = 0x00100000
 
-# basic configuration constants
-DRIVER_NAME = "python-oracledb"
-INSTALLATION_URL = "https://python-oracledb.readthedocs.io/en/" \
-                   "/latest/user_guide/initialization.html" \
-                   "#setting-the-oracle-client-library-directory"
-ENCODING = "UTF-8"
+# vector metadata flags
+VECTOR_META_FLAG_FLEXIBLE_DIM = 0x01
+VECTOR_META_FLAG_SPARSE_VECTOR = 0x02
